<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="obsolete">Un client YouTube ricco di funzioni per Nokia N900. Questa è una versione sperimentale rilasciata utilizzando QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.9.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation>Un client YouTube ricco di funzioni che permette di visualizzare, riprodurre e scaricare video,ed in più una gestione account completa. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation>Nuovo Account</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation>Modifica Account</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation>Errore database. Impossibile salvare account</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="94"/>
        <source>Password</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="107"/>
        <source>Default?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../AccountsDialog.qml" line="35"/>
        <source>Database error. Unable to delete account</source>
        <translation>Errore database. Impossibile cancellare l&apos;account</translation>
    </message>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation>Account di YouTube</translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation>Aggiungi Commento</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation>Condividi Tramite </translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="74"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="111"/>
        <source>Message</source>
        <translation>Messaggio</translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation>Aggiungi a Playlist</translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <source>Delete from archive</source>
        <translation type="obsolete">Cancella dall&apos;archivio</translation>
    </message>
    <message>
        <source>Delete from device</source>
        <translation type="obsolete">Cancella dal dispositivo</translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="93"/>
        <source>Deleted from archive</source>
        <translation>Cancellato dall&apos;archivio</translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="96"/>
        <location filename="../ArchiveListView.qml" line="116"/>
        <source>Unable to delete from archive</source>
        <translation>Impossibile cancellare dall&apos;archivio</translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="45"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation>Modifica Utente Attuale</translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="19"/>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <source>By </source>
        <translation>Da </translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source> on </source>
        <translation> il </translation>
    </message>
</context>
<context>
    <name>ConfirmDeleteDialog</name>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="30"/>
        <source>Confirm Delete</source>
        <translation>Conferma Eliminazione</translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="42"/>
        <source>Please choose from where you wish to delete the selected videos</source>
        <translation>Seleziona da dove vuoi cancellare i video selezionati</translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="55"/>
        <source>Archive</source>
        <translation>Archivio</translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="65"/>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation>Fermati!</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation>cuteTube sta scaricando. Vuoi veramente uscire?</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <source>English</source>
        <translation type="obsolete">Inglese</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="obsolete">Tedesco</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="obsolete">Olandese</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="obsolete">Polacco</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="253"/>
        <source>Video deleted from device</source>
        <translation>Video cancellato dal dispositivo</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="256"/>
        <source>Unable to delete video</source>
        <translation>Impossibile cancellare il video</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="260"/>
        <source>Video not found</source>
        <translation>Video non trovato</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="315"/>
        <source>Copied to clipboard</source>
        <translation>Copiato negli appunti</translation>
    </message>
</context>
<context>
    <name>DownloadListDelegate</name>
    <message>
        <source>Paused</source>
        <translation type="obsolete">In Pausa</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">In Coda</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Fallito</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">In Download</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Fallito</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">In Download</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">In Pausa</translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation>Selezionare il File Video</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Impostazioni</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="115"/>
        <source>My Channel</source>
        <translation>Il Mio Canale</translation>
    </message>
    <message>
        <source>Most Recent</source>
        <translation type="obsolete">I Più Recenti</translation>
    </message>
    <message>
        <source>Most Viewed</source>
        <translation type="obsolete">I Più Visti</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="185"/>
        <source>Archive</source>
        <translation>Archivio</translation>
    </message>
</context>
<context>
    <name>InboxDelegate</name>
    <message>
        <location filename="../InboxDelegate.qml" line="44"/>
        <location filename="../InboxDelegate.qml" line="46"/>
        <source>From </source>
        <translation>Da </translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="45"/>
        <location filename="../InboxDelegate.qml" line="47"/>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source> on </source>
        <translation> il </translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source>By </source>
        <translation>Da </translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="145"/>
        <source>Views</source>
        <translation>Visualizzazioni</translation>
    </message>
</context>
<context>
    <name>InboxDialog</name>
    <message>
        <location filename="../InboxDialog.qml" line="57"/>
        <source>Inbox</source>
        <translation>Posta in Arrivo</translation>
    </message>
    <message>
        <location filename="../InboxDialog.qml" line="69"/>
        <source>No messages found</source>
        <translation>Nessun messaggio trovato</translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <source>Back</source>
        <translation type="obsolete">Indietro</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Esci</translation>
    </message>
    <message>
        <location filename="../MenuBar.qml" line="150"/>
        <source>Sort</source>
        <translation>Ordina</translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <source>Upload video</source>
        <translation type="obsolete">Carica video</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="91"/>
        <source>My Uploads</source>
        <translation>I Miei Video</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="97"/>
        <source>Uploads</source>
        <translation>Caricati</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="115"/>
        <source>My Favourites</source>
        <translation>I Miei Preferiti</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="121"/>
        <source>Favourites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="145"/>
        <source>Playlists</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="169"/>
        <source>Subscriptions</source>
        <translation>Iscrizioni</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="184"/>
        <source>Signed in as:</source>
        <translation>Accesso effettuato come:</translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation>Nuova Playlist</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="59"/>
        <source>Description (optional)</source>
        <translation>Descrizione (facoltativa)</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Private?</source>
        <translation>Privato?</translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation>Ciao!</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation>Il mio nome è Cutey. Il mio amico Clippy mi ha detto che è la prima volta che usi cuteTube. Vuoi aggiungere un nuovo accaunt di YouTube?</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation>Salta</translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="55"/>
        <source>No active downloads</source>
        <translation>Nessun download attivo</translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="151"/>
        <source>Downloads</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation>Autorizzazione Per </translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation>Errore nell&apos;ottenere l&apos;autorizzazione Facebook</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation>Inserisci il codice</translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="30"/>
        <source> videos</source>
        <translation> video</translation>
    </message>
</context>
<context>
    <name>PlaylistDialog</name>
    <message>
        <location filename="../PlaylistDialog.qml" line="114"/>
        <source>Playlist Info</source>
        <translation>Info Playlist</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="159"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="165"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="185"/>
        <source>Created</source>
        <translation>Creata</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="191"/>
        <source>Updated</source>
        <translation>Ultimo aggiornamento</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="219"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="237"/>
        <source>No description</source>
        <translation>Nessuna descrizione</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="252"/>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="276"/>
        <source>Download</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Scarica video</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Scarica audio</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Aggiungi ai preferiti</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Aggiungi a playlist</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Copia negli appunti</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="90"/>
        <source>Video(s) deleted from playlist</source>
        <translation>Video cancellato(i) dalla playlist</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="111"/>
        <source>No videos found</source>
        <translation>Nessun video trovato</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="169"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="183"/>
        <source>Updated</source>
        <translation>Ultimo aggiornamento</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="206"/>
        <source>Play all</source>
        <translation>Riproduci tutti</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="214"/>
        <source>Loading playlist videos. Please wait</source>
        <translation>Caricamento dei video della playlist. Attendere</translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="50"/>
        <source>New playlist created</source>
        <translation>Nuova playlist creata</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="54"/>
        <source>Playlist deleted</source>
        <translation>Playlist cancellata</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation type="obsolete">Nuova playlist</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="87"/>
        <source>No playlists found</source>
        <translation>Nessuna playlist trovata</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <location filename="../ProxyDialog.qml" line="30"/>
        <source>Network Proxy</source>
        <translation>Rete Proxy</translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="44"/>
        <source>Host (e.g. 192.168.100.1)</source>
        <translation>Host (es. 192.168.100.1)</translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="51"/>
        <source>Port (e.g. 8080)</source>
        <translation>Porta (es. 8080)</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Date</source>
        <translation type="obsolete">Data</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation type="obsolete">Pertinenza</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="obsolete">Voto</translation>
    </message>
    <message>
        <source>Views</source>
        <translation type="obsolete">Numero di visualizzazioni</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="183"/>
        <source>Order by:</source>
        <translation>Ordina per:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Mobile</source>
        <translation></translation>
    </message>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Alta Qualità</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Automatically</source>
        <translation>Automaticamente</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Manually</source>
        <translation>Manualmente</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>On</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Off</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Automatic</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Landscape</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Portrait</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Russian</source>
        <translation>Russo</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Portuguese</source>
        <translation>Portoghese</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most recent</source>
        <translation>I più recenti</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most viewed</source>
        <translation>I più visti</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Archive</source>
        <translation>Archivio</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Latest subscription videos</source>
        <translation>Novità da iscrizioni</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My uploads</source>
        <translation>I miei video</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My favourites</source>
        <translation>I miei preferiti</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="187"/>
        <location filename="../SettingsDialog.qml" line="338"/>
        <source>Media Player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Light</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>High quality</source>
        <translation>Alta qualità</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>360p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>480p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>720p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Dark</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Midnight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>English</source>
        <translation>Inglese</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>German</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Finnish</source>
        <translation>Finlandese</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Dutch</source>
        <translation>Olandese</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Polish</source>
        <translation>Polacco</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">In Coda</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">In Pausa</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="121"/>
        <source>Your settings have been saved</source>
        <translation>Le tue impostazioni sono state salvate</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="126"/>
        <location filename="../SettingsDialog.qml" line="169"/>
        <source>Download Path</source>
        <translation>Percorso Download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="128"/>
        <source>Download Location</source>
        <translation>Destinazione Download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="136"/>
        <location filename="../SettingsDialog.qml" line="196"/>
        <source>Network Proxy</source>
        <translation>Rete Proxy</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="160"/>
        <location filename="../SettingsDialog.qml" line="347"/>
        <source>Playback Quality</source>
        <translation>Qualità Riproduzione</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="163"/>
        <location filename="../SettingsDialog.qml" line="356"/>
        <source>Download Quality</source>
        <translation>Qualità Download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="166"/>
        <location filename="../SettingsDialog.qml" line="322"/>
        <source>Start Downloads</source>
        <translation>Inizia Download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="172"/>
        <location filename="../SettingsDialog.qml" line="372"/>
        <source>Category Feed One</source>
        <translation>Feed Categoria Uno</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="175"/>
        <location filename="../SettingsDialog.qml" line="381"/>
        <source>Category Feed Two</source>
        <translation>Feed Categoria Due</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="178"/>
        <location filename="../SettingsDialog.qml" line="390"/>
        <source>Order Category Videos By</source>
        <translation>Ordina Categoria Video Per</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="181"/>
        <location filename="../SettingsDialog.qml" line="406"/>
        <source>Safe Search</source>
        <translation>Ricerca Sicura</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="184"/>
        <location filename="../SettingsDialog.qml" line="485"/>
        <source>Screen Orientation</source>
        <translation>Orientamento Schermo</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="190"/>
        <location filename="../SettingsDialog.qml" line="449"/>
        <location filename="../SettingsDialog.qml" line="451"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="193"/>
        <location filename="../SettingsDialog.qml" line="458"/>
        <location filename="../SettingsDialog.qml" line="460"/>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="199"/>
        <location filename="../SettingsDialog.qml" line="509"/>
        <source>Widget Feed One</source>
        <translation>Feed Widget Uno</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="202"/>
        <location filename="../SettingsDialog.qml" line="518"/>
        <source>Widget Feed Two</source>
        <translation>Feed Widget Due</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="205"/>
        <location filename="../SettingsDialog.qml" line="527"/>
        <source>Widget Feed Three</source>
        <translation>Feed Widget Tre</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="208"/>
        <location filename="../SettingsDialog.qml" line="536"/>
        <source>Widget Feed Four</source>
        <translation>Feed Widget Quattro</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="217"/>
        <source>Your saved searches have been cleared</source>
        <translation>Le tue ricerche salvate sono state cancellate</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="220"/>
        <source>Database error. Unable to clear searches</source>
        <translation>Errore database. Impossibile cancellare le ricerche</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="229"/>
        <source>Your facebook token has been deleted</source>
        <translation>Il tuo permesso facebook è stato cancellato</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="232"/>
        <source>Database error. Unable to delete facebook token</source>
        <translation>Errore database. Impossibile cancellare il permesso facebook</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="279"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="303"/>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="311"/>
        <source>Network proxy</source>
        <translation>Rete proxy</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="328"/>
        <source>Media</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="345"/>
        <source>Playback quality</source>
        <translation>Qualità riproduzione</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="354"/>
        <source>Download quality</source>
        <translation>Qualità download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="362"/>
        <source>YouTube categories</source>
        <translation>Categorie YouTube</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="370"/>
        <source>Category feed one</source>
        <translation>Feed categoria uno</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="379"/>
        <source>Category feed two</source>
        <translation>Feed categoria due</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="388"/>
        <source>Order category videos by</source>
        <translation>Ordina categoria video per</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="422"/>
        <source>Social networks</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="433"/>
        <source>Delete facebook token</source>
        <translation>Cancella permesso facebook</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="499"/>
        <source>Widget</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="507"/>
        <source>Feed one</source>
        <translation>Feed uno</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="516"/>
        <source>Feed two</source>
        <translation>Feed due</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="525"/>
        <source>Feed three</source>
        <translation>Feed tre</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="534"/>
        <source>Feed four</source>
        <translation>Feed quattro</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="320"/>
        <source>Start downloads</source>
        <translation>Inizia download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="396"/>
        <source>YouTube searches</source>
        <translation>Ricerche YouTube</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="441"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="466"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="474"/>
        <source>Download location</source>
        <translation>Destinazione download</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="404"/>
        <source>Safe search</source>
        <translation>Ricerca sicura</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="483"/>
        <source>Screen orientation</source>
        <translation>Orientamento schermo</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="336"/>
        <source>Media player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="312"/>
        <source>None</source>
        <translation>Nessuna</translation>
    </message>
    <message>
        <source>Feed One</source>
        <translation type="obsolete">Feed Uno</translation>
    </message>
    <message>
        <source>Feed Two</source>
        <translation type="obsolete">Feed Due</translation>
    </message>
    <message>
        <source>Feed Three</source>
        <translation type="obsolete">Feed Tre</translation>
    </message>
    <message>
        <source>Feed Four</source>
        <translation type="obsolete">Feed Quattro</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="415"/>
        <source>Clear saved searches</source>
        <translation>Cancella ricerche salvate</translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation>Errore - Il server ha risposto: </translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="34"/>
        <source>Latest Subscriptions Videos</source>
        <translation>Novità da Iscrizioni</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="41"/>
        <source>You have unsubscribed to this channel</source>
        <translation>Ti sei cancellato da questo canale</translation>
    </message>
    <message>
        <source>You have unsubscribed to &apos;</source>
        <translation type="obsolete">Ti sei cancellato da &apos;</translation>
    </message>
    <message>
        <source>Latest Subscription Videos</source>
        <translation type="obsolete">Novità da Iscrizioni</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="85"/>
        <source>No subscriptions found</source>
        <translation>Nessuna iscrizione trovata</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Cars &amp; Vehicles</source>
        <translation>Auto &amp; Veicoli</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Comedy</source>
        <translation>Umorismo</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Education</source>
        <translation>Istruzione</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Entertainment</source>
        <translation>Intrattenimento</translation>
    </message>
    <message>
        <source>Film and Animation</source>
        <translation type="obsolete">Film e Animazione</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Gaming</source>
        <translation>Giochi</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Film &amp; Animation</source>
        <translation>Film &amp; Animazione</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Howto &amp; Style</source>
        <translation>Fai da te &amp; Stile</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>News &amp; Politics</source>
        <translation>Notizie &amp; Politica</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>Non-profits &amp; Activism</source>
        <translation>Non profit &amp; Attivismo</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>People &amp; Blogs</source>
        <translation>Persone &amp; Blog</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Pets &amp; Animals</source>
        <translation>Animali</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Science &amp; Technology</source>
        <translation>Scienze &amp; Tecnologie</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Sport</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Travel &amp; Events</source>
        <translation>Viaggi &amp; Eventi</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="29"/>
        <location filename="../UploadDialog.qml" line="220"/>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="118"/>
        <source>Upload Video</source>
        <translation>Carica Video</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="143"/>
        <source>File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="152"/>
        <location filename="../UploadDialog.qml" line="228"/>
        <source>None chosen</source>
        <translation>Nessuna scelta</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="168"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="181"/>
        <source>Description (optional)</source>
        <translation>Descrizione (facoltativa)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="193"/>
        <source>Tags (seperated by commas)</source>
        <translation>Tag (separati da virgole)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="206"/>
        <source>Private?</source>
        <translation>Privato?</translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation>Iniziando il caricamento</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation>Avanzamento Upload</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation>Nome File</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation>Upload in corso</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation>Interrompi</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="106"/>
        <source>Profile</source>
        <translation>Profilo</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="152"/>
        <source>Uploads</source>
        <translation>Caricati</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="158"/>
        <source>Subscribers</source>
        <translation>Iscritti</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="178"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="184"/>
        <source>Age</source>
        <translation>Età</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="197"/>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <location filename="../UserInfoDialog.qml" line="221"/>
        <source>None</source>
        <translation>Nessuna</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="203"/>
        <source>Gender</source>
        <translation>Genere</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="209"/>
        <source>Location</source>
        <translation>Luogo</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <source>Male</source>
        <translation>Uomo</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <source>Female</source>
        <translation>Donna</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="236"/>
        <source>About</source>
        <translation>Informazioni personali</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="254"/>
        <source>No info</source>
        <translation>Nessuna informazione</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="269"/>
        <source>Unsubscribe</source>
        <translation>Cancellati</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="269"/>
        <source>Subscribe</source>
        <translation>Iscriviti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="obsolete">Video</translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="127"/>
        <source>You have subscribed to &apos;</source>
        <translation>Ti sei iscritto a &apos;</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="131"/>
        <source>You have unsubscribed to &apos;</source>
        <translation>Ti sei cancellato da &apos;</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Scarica video</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Scarica audio</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Aggiungi ai preferiti</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Aggiungi a playlist</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Copia negli appunti</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="151"/>
        <source>No videos found</source>
        <translation>Nessun video trovato</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="209"/>
        <source>Subscribers</source>
        <translation>Iscritti</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="223"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="246"/>
        <source>Unsubscribe</source>
        <translation>Cancellati</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="246"/>
        <source>Subscribe</source>
        <translation>Iscriviti</translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="15"/>
        <source>No description</source>
        <translation>Nessuna descrizione</translation>
    </message>
    <message>
        <source>Your comment has been added</source>
        <translation type="obsolete">Il tuo commento è stato aggiunto</translation>
    </message>
    <message>
        <source>Your rating has been added</source>
        <translation type="obsolete">Il tuo voto è stato aggiunto</translation>
    </message>
    <message>
        <source>Video shared on facebook</source>
        <translation type="obsolete">Video condiviso su Facebook</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Aggiungi ai preferiti</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Aggiungi a playlist</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Copia negli appunti</translation>
    </message>
    <message>
        <source>Share via facebook</source>
        <translation type="obsolete">Condividi via Facebook</translation>
    </message>
    <message>
        <source>You are not signed in to a YouTube account</source>
        <translation type="obsolete">Non hai effettuato l&apos;accesso con un account YouTube</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="240"/>
        <source>Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="278"/>
        <source>Comments</source>
        <translation>Commenti</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="316"/>
        <source>Related</source>
        <translation>Correlati</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="401"/>
        <location filename="../VideoInfoView.qml" line="404"/>
        <source>By </source>
        <translation>Da </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="403"/>
        <location filename="../VideoInfoView.qml" line="406"/>
        <source> on </source>
        <translation> il </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="474"/>
        <source>Views</source>
        <translation>Visualizzazioni</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="488"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="504"/>
        <source>Tags</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="514"/>
        <source>No tags</source>
        <translation>Nessun Tag</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="583"/>
        <source>No comments</source>
        <translation>Nessun commento</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="583"/>
        <source> comments</source>
        <translation> commenti</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="697"/>
        <source>No related videos</source>
        <translation>Nessun video correlato</translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="51"/>
        <source>By </source>
        <translation>Da </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="51"/>
        <source> on </source>
        <translation> il </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="101"/>
        <source>Views</source>
        <translation>Visualizzazioni</translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Scarica video</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Scarica audio</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Aggiungi ai preferiti</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Aggiungi a playlist</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Copia negli appunti</translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="79"/>
        <source>Video(s) deleted from favourites</source>
        <translation>Video cancellato(i) dai preferiti</translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="101"/>
        <source>No videos found</source>
        <translation>Nessun video trovato</translation>
    </message>
</context>
<context>
    <name>VideoPlaybackView</name>
    <message>
        <source>Error: Unable to retrieve video</source>
        <translation type="obsolete">Errore: Impossibile recuperare il video</translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="165"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Nessun video trovato</translation>
    </message>
</context>
<context>
    <name>XHamsterInfoView</name>
    <message>
        <source>Related</source>
        <translation type="obsolete">Correlati</translation>
    </message>
    <message>
        <source>By </source>
        <translation type="obsolete">Da </translation>
    </message>
    <message>
        <source> on </source>
        <translation type="obsolete"> il </translation>
    </message>
    <message>
        <source>Views </source>
        <translation type="obsolete">Visualizzazioni</translation>
    </message>
</context>
<context>
    <name>XHamsterListView</name>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Scarica video</translation>
    </message>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Nessun video trovato</translation>
    </message>
</context>
<context>
    <name>YouJizzInfoView</name>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Copia negli appunti</translation>
    </message>
    <message>
        <source>Related</source>
        <translation type="obsolete">Correlati</translation>
    </message>
    <message>
        <source>Views </source>
        <translation type="obsolete">Visualizzazioni</translation>
    </message>
</context>
<context>
    <name>YouJizzListView</name>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Scarica video</translation>
    </message>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Nessun video trovato</translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="43"/>
        <source>Error obtaining access token</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="54"/>
        <source>Authentication failed</source>
        <translation>Autenticazione fallita</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="58"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation>Hai effettuato l&apos;accesso a YouTube come &apos;</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="120"/>
        <location filename="../../../youtube.cpp" line="229"/>
        <source>Error - Server repsonse is: </source>
        <translation>Errore - Il server ha risposto: </translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="170"/>
        <location filename="../../../youtube.cpp" line="178"/>
        <source>Upload aborted</source>
        <translation>Caricamento interrotto</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="185"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation>Caricamento interrotto. Tenetativo di ripresa...</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="189"/>
        <source>Upload failed</source>
        <translation>Caricamento fallito</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="195"/>
        <source>Upload is completed</source>
        <translation>Caricamento completato</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="400"/>
        <source>Error: Unable to retrieve video</source>
        <translation>Errore: Impossibile recuperare il video</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Light</source>
        <translation type="obsolete">Luce</translation>
    </message>
    <message>
        <source>Video(s) added to download queue</source>
        <translation type="obsolete">Video aggiunto(i) alla coda download</translation>
    </message>
    <message>
        <location filename="../main.qml" line="462"/>
        <source>Video(s) already in download queue</source>
        <translation>Video già presente(i) nella coda download</translation>
    </message>
    <message>
        <location filename="../main.qml" line="463"/>
        <source>Audio track(s) added to download queue</source>
        <translation>Traccia(e) audio aggiunta(e) alla coda download</translation>
    </message>
    <message>
        <location filename="../main.qml" line="464"/>
        <source>Audio track(s) already in download queue</source>
        <translation>Traccia(e) audio già presente(i) nella coda download</translation>
    </message>
    <message>
        <source>Video added to favourites</source>
        <translation type="obsolete">Video aggiunto ai preferiti</translation>
    </message>
    <message>
        <source>Video added to playlist</source>
        <translation type="obsolete">Video aggiunto alla playlist</translation>
    </message>
    <message>
        <location filename="../main.qml" line="459"/>
        <source>New playlist created</source>
        <translation>Nuova playlist creata</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Converting</source>
        <translation>In Conversione</translation>
    </message>
    <message>
        <location filename="../main.qml" line="270"/>
        <source>Conversion of &apos;</source>
        <translation>Conversione di &apos;</translation>
    </message>
    <message>
        <location filename="../main.qml" line="453"/>
        <source>Your rating has been added</source>
        <translation>Il tuo voto è stato aggiunto</translation>
    </message>
    <message>
        <location filename="../main.qml" line="455"/>
        <source>Your comment has been added</source>
        <translation>Il tuo commento è stato aggiunto</translation>
    </message>
    <message>
        <location filename="../main.qml" line="460"/>
        <source>Video shared on facebook</source>
        <translation>Video condiviso su Facebook</translation>
    </message>
    <message>
        <location filename="../main.qml" line="461"/>
        <source>Videos(s) added to download queue</source>
        <translation>Video aggiunto(i) alla coda download</translation>
    </message>
    <message>
        <location filename="../main.qml" line="465"/>
        <source>You are not signed in to a YouTube account</source>
        <translation>Non hai effettuato l&apos;accesso con un account YouTube</translation>
    </message>
    <message>
        <location filename="../main.qml" line="466"/>
        <source>No YouTube account found</source>
        <translation>Nessun account YouTube trovato</translation>
    </message>
    <message>
        <location filename="../main.qml" line="467"/>
        <source>Use the cuteTube Player to access this feature</source>
        <translation>Utilizza il player di cuteTube per accedere a questa funzione</translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Cars &amp; Vehicles</source>
        <translation>Auto &amp; Veicoli</translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Comedy</source>
        <translation>Umorismo</translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Education</source>
        <translation>Istruzione</translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Entertainment</source>
        <translation>Intrattenimento</translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Film &amp; Animation</source>
        <translation>Film &amp; Animazione</translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Gaming</source>
        <translation>Giochi</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>Howto &amp; Style</source>
        <translation>Fai da te &amp; Stile</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>News &amp; Politics</source>
        <translation>Notizie &amp; Politica</translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>Non-profits &amp; Activism</source>
        <translation>Non profit &amp; Attivismo</translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>People &amp; Blogs</source>
        <translation>Persone &amp; Blog</translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Pets &amp; Animals</source>
        <translation>Animali</translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Science &amp; Technology</source>
        <translation>Scienze &amp; Tecnologie</translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Sport</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Travel &amp; Events</source>
        <translation>Viaggi &amp; Eventi</translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Relevance</source>
        <translation>Pertinenza</translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Views</source>
        <translation>Visualizzazioni</translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Rating</source>
        <translation>Voto</translation>
    </message>
    <message>
        <location filename="../main.qml" line="454"/>
        <source>You cannot rate your own videos</source>
        <translation>Non puoi votare i tuoi video</translation>
    </message>
    <message>
        <location filename="../main.qml" line="456"/>
        <source>Video(s) added to favourites</source>
        <translation>Video aggiunto(i) ai preferiti</translation>
    </message>
    <message>
        <location filename="../main.qml" line="457"/>
        <source>Video already in favourites</source>
        <translation>Il video è già nei preferiti</translation>
    </message>
    <message>
        <location filename="../main.qml" line="458"/>
        <source>Video(s) added to playlist</source>
        <translation>Video aggiunto(i) alla playlist</translation>
    </message>
    <message>
        <location filename="../main.qml" line="468"/>
        <source>Unable to play videos at 360p quality or higher</source>
        <translation>Impossibile riprodurre il video in qualità 360p o superiore</translation>
    </message>
    <message>
        <location filename="../main.qml" line="270"/>
        <source>&apos; failed</source>
        <translation>&apos; fallita</translation>
    </message>
    <message>
        <source>High quality</source>
        <translation type="obsolete">Altà qualità</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Queued</source>
        <translation>In Coda</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Paused</source>
        <translation>In Pausa</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Downloading</source>
        <translation>In Download</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Failed</source>
        <translation>Fallito</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Most Recent</source>
        <translation>I Più Recenti</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Most Viewed</source>
        <translation>I Più Visti</translation>
    </message>
</context>
<context>
    <name>mainscripts</name>
    <message>
        <source>My Channel</source>
        <translation type="obsolete">Il Mio Canale</translation>
    </message>
    <message>
        <source>Archive</source>
        <translation type="obsolete">Archivio</translation>
    </message>
    <message>
        <source>My Playlists</source>
        <translation type="obsolete">Le Mie Playlist</translation>
    </message>
    <message>
        <source>My Subscriptions</source>
        <translation type="obsolete">Le Mie Iscrizioni</translation>
    </message>
    <message>
        <source>Video Info</source>
        <translation type="obsolete">Info Video</translation>
    </message>
    <message>
        <source>Video Playback</source>
        <translation type="obsolete">Riproduzione Video</translation>
    </message>
    <message>
        <source>date</source>
        <translation type="obsolete">data</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">visualizzazioni</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">pertinenza</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">voto</translation>
    </message>
    <message>
        <source>Search </source>
        <translation type="obsolete">Cerca </translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Alta Qualità</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">In Pausa</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="obsolete">Automatico</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="obsolete">Data</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Inglese</translation>
    </message>
</context>
<context>
    <name>xtube</name>
    <message>
        <source>date</source>
        <translation type="obsolete">data</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">visualizzazioni</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">voto</translation>
    </message>
    <message>
        <source>Search </source>
        <translation type="obsolete">Cerca </translation>
    </message>
    <message>
        <source>Video Info</source>
        <translation type="obsolete">Info Video</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">pertinenza</translation>
    </message>
</context>
</TS>
